@@ -177,7 +177,7 @@
     </message>
     <message>
         <source>Smalle Eraser</source>
-        <translation>ممحاة صغيرة</translation>
+        <translation type="vanished">ممحاة صغيرة</translation>
     </message>
     <message>
         <source>Medium Eraser</source>
@@ -189,7 +189,7 @@
     </message>
     <message>
         <source>Color</source>
-        <translation>لون</translation>
+        <translation type="vanished">لون</translation>
     </message>
     <message>
         <source>Back</source>
@@ -697,11 +697,11 @@
     </message>
     <message>
         <source>Flash Trap</source>
-        <translation>قلاش تراب</translation>
+        <translation type="vanished">قلاش تراب</translation>
     </message>
     <message>
         <source>Trap Flash Content</source>
-        <translation>محتوى فلاش تراب</translation>
+        <translation type="vanished">محتوى فلاش تراب</translation>
     </message>
     <message>
         <source>Web Trap</source>
@@ -811,6 +811,38 @@
         <source>Reset grid size</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Small Eraser</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color 5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Capture Web Content</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -868,6 +900,14 @@
         <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
         <translation>هل تريدون حقا إزالة صفحة واحدة من الوثيقة &apos;%0&apos; المختارة؟</translation>
     </message>
+    <message>
+        <source>Loading scene (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moving cached scenes (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplication</name>
@@ -879,6 +919,10 @@
         <source>Podcast</source>
         <translation>بودكاست</translation>
     </message>
+    <message>
+        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplicationController</name>
@@ -909,6 +953,10 @@
         <source>Grid size</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Draw intermediate grid lines</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBBoardController</name>
@@ -968,6 +1016,10 @@
         <source>Deleting page %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Color</source>
+        <translation type="unfinished">لون</translation>
+    </message>
 </context>
 <context>
     <name>UBBoardPaletteManager</name>
@@ -1199,6 +1251,10 @@
         <source>Title page</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Refreshing Document Thumbnails View (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1249,6 +1305,10 @@
         <source>Page %0</source>
         <translation>صفحة %0</translation>
     </message>
+    <message>
+        <source>Generating thumbnails for board (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentPublisher</name>
@@ -1321,6 +1381,10 @@ Providing a new name will create a new document.</source>
         <source>Are you sure you want to remove the selected item(s) ?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copying page %1/%2</source>
+        <translation type="unfinished">نسخ الصفحة 1% / 2%</translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentTreeWidget</name>
@@ -1616,7 +1680,7 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Animations</source>
-        <translation>حركات</translation>
+        <translation type="vanished">حركات</translation>
     </message>
     <message>
         <source>Interactivities</source>
@@ -1945,6 +2009,14 @@ Do you want to ignore these errors for this host?</source>
         <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Renaming pages (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retrieving all your documents (found : %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBPlatformUtils</name>
@@ -2108,6 +2180,10 @@ Do you want to ignore these errors for this host?</source>
         <source>%1 thumbnails generated ...</source>
         <translation>1 % صور مصغرة مولّدة</translation>
     </message>
+    <message>
+        <source>Loading thumbnail (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBThumbnailTextItem</name>
@@ -2146,6 +2222,10 @@ Do you want to ignore these errors for this host?</source>
         <source>Cache</source>
         <translation>تخزين مؤقت</translation>
     </message>
+    <message>
+        <source>Axes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBTrapFlashController</name>
@@ -2506,6 +2586,13 @@ Please reboot the application to access the updated documents.</source>
         <translation>فتح في علامة تبويب جديدة</translation>
     </message>
 </context>
+<context>
+    <name>XPDFRenderer</name>
+    <message>
+        <source>Processing...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>YouTubePublishingDialog</name>
     <message>
@@ -2840,6 +2927,30 @@ p, li { white-space: pre-wrap; }
         <source>Check if Open-Sankoré data could be imported at launch</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Documents Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display date column on alphabetical sort</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Empty trash for documents older than</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PDF Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>trapFlashDialog</name>
@@ -2849,7 +2960,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Select a flash to trap</source>
-        <translation>اختيار فلاش للامساك به</translation>
+        <translation type="vanished">اختيار فلاش للامساك به</translation>
     </message>
     <message>
         <source>about:blank</source>
@@ -2863,5 +2974,9 @@ p, li { white-space: pre-wrap; }
         <source>Create Application</source>
         <translation>إنشاء تطبيق</translation>
     </message>
+    <message>
+        <source>Select a content to capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
