@@ -374,7 +374,7 @@
     </message>
     <message>
         <source>Trap Flash Content</source>
-        <translation>Přenést obsah ve Flashi</translation>
+        <translation type="vanished">Přenést obsah ve Flashi</translation>
     </message>
     <message>
         <source>Import</source>
@@ -562,7 +562,7 @@
     </message>
     <message>
         <source>Flash Trap</source>
-        <translation>Přenést Flash</translation>
+        <translation type="vanished">Přenést Flash</translation>
     </message>
     <message>
         <source>Window Capture</source>
@@ -840,6 +840,10 @@
         <source>Draw intermediate grid lines</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Capture Web Content</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -897,6 +901,14 @@
         <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
         <translation>Opravdu chcete odstranit 1 stránku z vybraného dokumentu &apos;%0&apos;?</translation>
     </message>
+    <message>
+        <source>Loading scene (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moving cached scenes (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplication</name>
@@ -908,6 +920,10 @@
         <source>Page Size</source>
         <translation>Velikost stránky</translation>
     </message>
+    <message>
+        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplicationController</name>
@@ -1229,6 +1245,10 @@
         <source>Title page</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Refreshing Document Thumbnails View (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1279,6 +1299,10 @@
         <source>Page %0</source>
         <translation>Stránka %0</translation>
     </message>
+    <message>
+        <source>Generating thumbnails for board (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentReplaceDialog</name>
@@ -1969,6 +1993,14 @@ Chcete ignorovat tyto chyby na tomto serveru?</translation>
         <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Renaming pages (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retrieving all your documents (found : %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBPlatformUtils</name>
@@ -2132,6 +2164,10 @@ Chcete ignorovat tyto chyby na tomto serveru?</translation>
         <source>Generating preview thumbnails ...</source>
         <translation>Vytváří se miniatury obrázků ...</translation>
     </message>
+    <message>
+        <source>Loading thumbnail (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBThumbnailTextItem</name>
@@ -2910,7 +2946,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Select a flash to trap</source>
-        <translation>Vyberte flash, který chcete přenést</translation>
+        <translation type="vanished">Vyberte flash, který chcete přenést</translation>
     </message>
     <message>
         <source>about:blank</source>
@@ -2924,5 +2960,9 @@ p, li { white-space: pre-wrap; }
         <source>Create Application</source>
         <translation>Vytvořit aplikaci</translation>
     </message>
+    <message>
+        <source>Select a content to capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
