@@ -697,11 +697,11 @@
     </message>
     <message>
         <source>Flash Trap</source>
-        <translation>Captura de elemento Flash</translation>
+        <translation type="vanished">Captura de elemento Flash</translation>
     </message>
     <message>
         <source>Trap Flash Content</source>
-        <translation>Capturar contido Flash</translation>
+        <translation type="vanished">Capturar contido Flash</translation>
     </message>
     <message>
         <source>Web Trap</source>
@@ -839,6 +839,10 @@
         <source>Draw intermediate grid lines</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Capture Web Content</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -896,6 +900,14 @@
         <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
         <translation>¿Está seguro de que quere eliminar 1 páxina do documento seleccionado.&apos;%0?</translation>
     </message>
+    <message>
+        <source>Loading scene (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moving cached scenes (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplication</name>
@@ -907,6 +919,10 @@
         <source>Podcast</source>
         <translation>Podcast</translation>
     </message>
+    <message>
+        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplicationController</name>
@@ -1238,6 +1254,10 @@
         <source>Title page</source>
         <translation>Páxina de título</translation>
     </message>
+    <message>
+        <source>Refreshing Document Thumbnails View (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1288,6 +1308,10 @@
         <source>Page %0</source>
         <translation>Páxina %0</translation>
     </message>
+    <message>
+        <source>Generating thumbnails for board (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentReplaceDialog</name>
@@ -1979,6 +2003,14 @@ Do you want to ignore these errors for this host?</source>
         <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
         <translation>OpenBoard perdeu o acceso ao repositorio de documentos &apos;%1&apos;. Desafortunadamente, a aplicación debe pecharse para evitar a corrrupción de datos. Tamén se poden perder os últimos cambios. </translation>
     </message>
+    <message>
+        <source>Renaming pages (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retrieving all your documents (found : %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBPlatformUtils</name>
@@ -2146,6 +2178,10 @@ Do you want to ignore these errors for this host?</source>
         <source>loading thumbnail of page %1</source>
         <translation type="vanished">cargando miniaturas da páxina %1</translation>
     </message>
+    <message>
+        <source>Loading thumbnail (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBThumbnailTextItem</name>
@@ -2901,7 +2937,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Select a flash to trap</source>
-        <translation>Seleccionar un flash para capturar</translation>
+        <translation type="vanished">Seleccionar un flash para capturar</translation>
     </message>
     <message>
         <source>about:blank</source>
@@ -2915,5 +2951,9 @@ p, li { white-space: pre-wrap; }
         <source>Create Application</source>
         <translation>Crear aplicación</translation>
     </message>
+    <message>
+        <source>Select a content to capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
