@@ -50,7 +50,7 @@
     <name>IntranetPodcastPublishingDialog</name>
     <message>
         <source>Publish Podcast to YouTube</source>
-        <translation>Podcast publikálása a YouTubera</translation>
+        <translation>Podcast közzététele a YouTube-on</translation>
     </message>
     <message>
         <source>Title</source>
@@ -441,7 +441,7 @@
     </message>
     <message>
         <source>Reload Current Page</source>
-        <translation>Aktuális oldal újratöltése</translation>
+        <translation>Jelenlegi oldal újratöltése</translation>
     </message>
     <message>
         <source>Load Home Page</source>
@@ -641,11 +641,11 @@
     </message>
     <message>
         <source>Add To New Page</source>
-        <translation>Hozzáadás új oldalhoz</translation>
+        <translation>Hozzáadás az új oldalhoz</translation>
     </message>
     <message>
         <source>Add Item To New Page</source>
-        <translation>Tartalom hozzáadása új oldalhoz</translation>
+        <translation>Elem hozzáadása az új oldalhoz</translation>
     </message>
     <message>
         <source>Add To Library</source>
@@ -653,7 +653,7 @@
     </message>
     <message>
         <source>Add Item To Library</source>
-        <translation>Tartalom hozzáadása a könyvtárhoz</translation>
+        <translation>Elem hozzáadása a könyvtárhoz</translation>
     </message>
     <message>
         <source>Pages</source>
@@ -701,11 +701,11 @@
     </message>
     <message>
         <source>Flash Trap</source>
-        <translation>Flash rögzítése</translation>
+        <translation type="vanished">Flash rögzítése</translation>
     </message>
     <message>
         <source>Trap Flash Content</source>
-        <translation>Flash tartalom rögzítése</translation>
+        <translation type="vanished">Flash tartalom rögzítése</translation>
     </message>
     <message>
         <source>Web Trap</source>
@@ -813,30 +813,34 @@
     </message>
     <message>
         <source>Small Eraser</source>
-        <translation type="unfinished"></translation>
+        <translation>Kis radír</translation>
     </message>
     <message>
         <source>Color 1</source>
-        <translation type="unfinished"></translation>
+        <translation>1. szín</translation>
     </message>
     <message>
         <source>Color 2</source>
-        <translation type="unfinished"></translation>
+        <translation>2. szín</translation>
     </message>
     <message>
         <source>Color 3</source>
-        <translation type="unfinished"></translation>
+        <translation>3. szín</translation>
     </message>
     <message>
         <source>Color 4</source>
-        <translation type="unfinished"></translation>
+        <translation>4. szín</translation>
     </message>
     <message>
         <source>Color 5</source>
-        <translation type="unfinished"></translation>
+        <translation>5. szín</translation>
     </message>
     <message>
         <source>Draw intermediate grid lines</source>
+        <translation>Köztes rácsvonalak rajzolása</translation>
+    </message>
+    <message>
+        <source>Capture Web Content</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -886,14 +890,22 @@
     </message>
     <message>
         <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
-        <translation>Biztosan el akarsz távolítani 1 oldalt a kiválasztott dokumentumból &apos;%0&apos;?</translation>
+        <translation>Biztosan szeretné eltávolítani 1 oldalt a kijelölt „%0”-dokumentumból?</translation>
     </message>
     <message>
         <source>Element ID = </source>
-        <translation type="unfinished"></translation>
+        <translation>Elem azonosítója = </translation>
     </message>
     <message>
         <source>Content is not supported in destination format.</source>
+        <translation>A tartalom nem támogatott célformátumban.</translation>
+    </message>
+    <message>
+        <source>Loading scene (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moving cached scenes (%1/%2)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -907,6 +919,10 @@
         <source>Podcast</source>
         <translation>Podcast</translation>
     </message>
+    <message>
+        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplicationController</name>
@@ -932,7 +948,7 @@
     </message>
     <message>
         <source>Board drawing...</source>
-        <translation type="vanished">Tábla rajzolása...</translation>
+        <translation type="vanished">Tábla rajzolása…</translation>
     </message>
 </context>
 <context>
@@ -943,7 +959,7 @@
     </message>
     <message>
         <source>Draw intermediate grid lines</source>
-        <translation type="unfinished"></translation>
+        <translation>Köztes rácsvonalak rajzolása</translation>
     </message>
 </context>
 <context>
@@ -990,11 +1006,11 @@
     </message>
     <message>
         <source>Saving document...</source>
-        <translation>Dokumentum mentése...</translation>
+        <translation>Dokumentum mentése…</translation>
     </message>
     <message>
         <source>Document has just been saved...</source>
-        <translation>Dokumentum éppen most mentve...</translation>
+        <translation>Dokumentum éppen most mentve…</translation>
     </message>
     <message>
         <source>Deleting page %1</source>
@@ -1002,7 +1018,7 @@
     </message>
     <message>
         <source>Color</source>
-        <translation type="unfinished">Szín</translation>
+        <translation>Szín</translation>
     </message>
 </context>
 <context>
@@ -1020,7 +1036,7 @@
     <name>UBBoardThumbnailsView</name>
     <message>
         <source>Loading page (%1/%2)</source>
-        <translation>Oldalak betöltése (%1/%2)</translation>
+        <translation>Oldalak betöltése: %1/%2</translation>
     </message>
 </context>
 <context>
@@ -1113,23 +1129,23 @@
     </message>
     <message>
         <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
-        <translation type="vanished">Biztosan szeretné eltávolítani a &apos;%1&apos; dokumentumot?</translation>
+        <translation type="vanished">Biztosan szeretné eltávolítani a(z) „%1” dokumentumot?</translation>
     </message>
     <message>
         <source>Empty Trash</source>
-        <translation type="vanished">Kuka kiürítése</translation>
+        <translation type="vanished">Törölt elemek kiürítése</translation>
     </message>
     <message>
         <source>Are you sure you want to empty trash?</source>
-        <translation type="vanished">Biztosan szeretné a kukát üríteni?</translation>
+        <translation type="vanished">Biztosan szeretné kiüríteni a törölt elemeket?</translation>
     </message>
     <message>
         <source>Emptying trash</source>
-        <translation type="vanished">Kuka kiürítése folyamatban</translation>
+        <translation type="vanished">Törölt elemek kiürítése folyamatban van…</translation>
     </message>
     <message>
         <source>Emptied trash</source>
-        <translation type="vanished">Kuka kiürítve</translation>
+        <translation type="vanished">Törölt elemek kiürítve</translation>
     </message>
     <message>
         <source>Remove Folder</source>
@@ -1137,7 +1153,7 @@
     </message>
     <message>
         <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
-        <translation type="vanished">Biztosan eltávolítja a(z) &apos;%1&apos; mappát és minden tartalmát?</translation>
+        <translation type="vanished">Biztosan szeretné eltávolítani a(z) „%1” mappát és az összes tartalmát?</translation>
     </message>
     <message>
         <source>No document selected!</source>
@@ -1149,7 +1165,7 @@
     </message>
     <message>
         <source>Importing file %1...</source>
-        <translation>%1 fájl importálása...</translation>
+        <translation>%1 fájl importálása…</translation>
     </message>
     <message>
         <source>Failed to import file ... </source>
@@ -1169,7 +1185,7 @@
     </message>
     <message>
         <source>Trash</source>
-        <translation>Kuka</translation>
+        <translation>Törölt elemek</translation>
     </message>
     <message>
         <source>Open Document</source>
@@ -1187,11 +1203,9 @@
         <source>Selection does not contain any image files!</source>
         <translation>A kiválasztásban nincs egyetlen kép sem!</translation>
     </message>
-    <message numerus="yes">
+    <message>
         <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
-        <translation type="vanished">
-            <numerusform>Biztosan szeretne eltávolítani %n oldalt a kiválasztott &apos;%1&apos; dokumentumból?</numerusform>
-        </translation>
+        <translation type="vanished">Biztosan szeretné eltávolítani %n oldalt a kiválasztott „%1” dokumentumból?</translation>
     </message>
     <message>
         <source>Folder does not contain any image files</source>
@@ -1203,11 +1217,11 @@
     </message>
     <message>
         <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
-        <translation>A &apos;%1&apos; dokumentum az OpenBoard újabb verziójával (%2) készült. Megnyitásával néhány információ elveszhet. Szeretné folytatni?</translation>
+        <translation>A(z) „%1” dokumentum az OpenBoard újabb verziójával (%2) készült. Megnyitásával néhány információ elveszhet. Szeretné folytatni?</translation>
     </message>
     <message>
         <source>Are you sure you want to remove all selected documents?</source>
-        <translation type="vanished">Biztosan szeretne eltávolítani minden kiválasztott dokumentumot?</translation>
+        <translation type="vanished">Biztosan szeretné eltávolítani minden kijelölt dokumentumot?</translation>
     </message>
     <message>
         <source>Remove multiple documents</source>
@@ -1217,19 +1231,23 @@
         <source>duplicated %1 page</source>
         <comment>duplicated %1 pages</comment>
         <translation type="unfinished">
-            <numerusform></numerusform>
+            <numerusform>%1 oldal másolata</numerusform>
         </translation>
     </message>
     <message>
         <source>Remove Item</source>
-        <translation type="unfinished"></translation>
+        <translation>Elem eltávolítása</translation>
     </message>
     <message>
         <source>Are you sure you want to remove the selected item(s) ?</source>
-        <translation type="unfinished"></translation>
+        <translation>Biztosan szeretné eltávolítani a kijelölt elem(ek)et?</translation>
     </message>
     <message>
         <source>Title page</source>
+        <translation>Címlap</translation>
+    </message>
+    <message>
+        <source>Refreshing Document Thumbnails View (%1/%2)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1261,7 +1279,7 @@
     </message>
     <message>
         <source>Inserting page %1 of %2</source>
-        <translation>%2 / %1 oldal beszúrása</translation>
+        <translation>Oldal beszúrása: %1/%2</translation>
     </message>
     <message>
         <source>Import successful.</source>
@@ -1280,6 +1298,10 @@
     <name>UBDocumentNavigator</name>
     <message>
         <source>Page %0</source>
+        <translation>%0. oldal</translation>
+    </message>
+    <message>
+        <source>Generating thumbnails for board (%1/%2)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1287,32 +1309,34 @@
     <name>UBDocumentReplaceDialog</name>
     <message>
         <source>Accept</source>
-        <translation type="unfinished">Elfogad</translation>
+        <translation>Elfogadás</translation>
     </message>
     <message>
         <source>Replace</source>
-        <translation type="unfinished"></translation>
+        <translation>Csere</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished">Mégse</translation>
+        <translation>Mégse</translation>
     </message>
     <message>
         <source>The name %1 is allready used.
 Keeping this name will replace the document.
 Providing a new name will create a new document.</source>
-        <translation type="unfinished"></translation>
+        <translation>A(z) %1 név már használatban van.
+Ennek a névnek a megtartása helyettesíti a dokumentumot.
+Új név megadása új dokumentumot hoz létre.</translation>
     </message>
 </context>
 <context>
     <name>UBDocumentTreeModel</name>
     <message>
         <source>My documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Saját dokumentumok</translation>
     </message>
     <message>
         <source>Trash</source>
-        <translation type="unfinished">Kuka</translation>
+        <translation>Törölt elemek</translation>
     </message>
     <message numerus="yes">
         <source>%1 pages copied</source>
@@ -1325,7 +1349,7 @@ Providing a new name will create a new document.</source>
     <name>UBDocumentTreeView</name>
     <message>
         <source>Copying page %1/%2</source>
-        <translation type="unfinished">%1/%2 oldal másolása</translation>
+        <translation>Oldal másolása: %1/%2</translation>
     </message>
     <message numerus="yes">
         <source>%1 pages copied</source>
@@ -1335,11 +1359,11 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Remove Item</source>
-        <translation type="unfinished"></translation>
+        <translation>Elem eltávolítása</translation>
     </message>
     <message>
         <source>Are you sure you want to remove the selected item(s) ?</source>
-        <translation type="unfinished"></translation>
+        <translation>Biztosan szeretné eltávolítani a kijelölt elem(ek)et?</translation>
     </message>
 </context>
 <context>
@@ -1350,13 +1374,11 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Copying page %1/%2</source>
-        <translation type="vanished">%1/%2 oldal másolása</translation>
+        <translation type="vanished">Oldal másolása: %1/%2</translation>
     </message>
-    <message numerus="yes">
+    <message>
         <source>%1 pages copied</source>
-        <translation type="vanished">
-            <numerusform>%1 oldal másolva</numerusform>
-        </translation>
+        <translation type="vanished">%1 oldal másolva</translation>
     </message>
 </context>
 <context>
@@ -1374,7 +1396,7 @@ Providing a new name will create a new document.</source>
     <name>UBDraggableThumbnail</name>
     <message>
         <source>Page %0</source>
-        <translation type="unfinished"></translation>
+        <translation>%0. oldal</translation>
     </message>
 </context>
 <context>
@@ -1392,7 +1414,7 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Exporting document...</source>
-        <translation>Dokumentum exportálása...</translation>
+        <translation>Dokumentum exportálása…</translation>
     </message>
     <message>
         <source>Export failed</source>
@@ -1415,23 +1437,23 @@ Providing a new name will create a new document.</source>
     <name>UBExportCFF</name>
     <message>
         <source>Export to IWB</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportálás IWB-formátumként</translation>
     </message>
     <message>
         <source>Export as IWB File</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportálás IWB-fájlformátumként</translation>
     </message>
     <message>
         <source>Exporting document...</source>
-        <translation type="unfinished">Dokumentum exportálása...</translation>
+        <translation>Dokumentum exportálása…</translation>
     </message>
     <message>
         <source>Export successful.</source>
-        <translation type="unfinished">Exportálás sikeres.</translation>
+        <translation>Az exportálás sikeres.</translation>
     </message>
     <message>
         <source>Export failed.</source>
-        <translation type="unfinished">Exportálás sikertelen.</translation>
+        <translation>Az exportálás sikertelen.</translation>
     </message>
 </context>
 <context>
@@ -1446,7 +1468,7 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Exporting %1 %2 of %3</source>
-        <translation>%1 exportálása %2/%3</translation>
+        <translation>%1 exportálása: %2/%3</translation>
     </message>
     <message>
         <source>Export to OpenBoard Format</source>
@@ -1457,27 +1479,27 @@ Providing a new name will create a new document.</source>
     <name>UBExportDocumentSetAdaptor</name>
     <message>
         <source>Failed to export...</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportálás sikertelen…</translation>
     </message>
     <message>
         <source>Export as UBX File</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportálás UBX-fájlként</translation>
     </message>
     <message>
         <source>Exporting document...</source>
-        <translation type="unfinished">Dokumentum exportálása...</translation>
+        <translation>Dokumentum exportálása…</translation>
     </message>
     <message>
         <source>Export successful.</source>
-        <translation type="unfinished">Exportálás sikeres.</translation>
+        <translation>Exportálás sikeres.</translation>
     </message>
     <message>
         <source>Export failed.</source>
-        <translation type="unfinished">Exportálás sikertelen.</translation>
+        <translation>Exportálás sikertelen.</translation>
     </message>
     <message>
         <source>Export to OpenBoard UBX Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportálás OpenBoard UBX-formátumként</translation>
     </message>
 </context>
 <context>
@@ -1499,7 +1521,7 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Exporting page %1 of %2</source>
-        <translation>%2 / %1 oldal exportálása</translation>
+        <translation>Oldal exportálása: %1/%2</translation>
     </message>
     <message>
         <source>Export to PDF</source>
@@ -1518,7 +1540,7 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Exporting document...</source>
-        <translation>Dokumentum exportálása...</translation>
+        <translation>Dokumentum exportálása…</translation>
     </message>
     <message>
         <source>Export successful.</source>
@@ -1627,14 +1649,14 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Trash</source>
-        <translation>Kuka</translation>
+        <translation>Törölt elemek</translation>
     </message>
 </context>
 <context>
     <name>UBFeaturesNewFolderDialog</name>
     <message>
         <source>Accept</source>
-        <translation>Elfogad</translation>
+        <translation>Elfogadás</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -1705,7 +1727,7 @@ Providing a new name will create a new document.</source>
     <name>UBGraphicsTextItem</name>
     <message>
         <source>&lt;Type Text Here&gt;</source>
-        <translation>&lt;Szöveg helye&gt;</translation>
+        <translation>&lt;Adja meg a szöveget ide&gt;</translation>
     </message>
 </context>
 <context>
@@ -1730,7 +1752,7 @@ Providing a new name will create a new document.</source>
     <name>UBGraphicsWidgetItem</name>
     <message>
         <source>Loading ...</source>
-        <translation>Betöltés ...</translation>
+        <translation>Betöltés folyamatban van…</translation>
     </message>
 </context>
 <context>
@@ -1748,30 +1770,30 @@ Providing a new name will create a new document.</source>
     <name>UBImportCFF</name>
     <message>
         <source>Common File Format (</source>
-        <translation type="unfinished"></translation>
+        <translation>Közös fájlformátum (</translation>
     </message>
     <message>
         <source>Importing file %1...</source>
-        <translation type="unfinished">%1 fájl importálása...</translation>
+        <translation>%1 fájl importálása…</translation>
     </message>
     <message>
         <source>Import of file %1 failed.</source>
-        <translation type="unfinished">%1 fájl importálása sikertelen.</translation>
+        <translation>%1 fájl importálása sikertelen.</translation>
     </message>
     <message>
         <source>Import successful.</source>
-        <translation type="unfinished">Importálás sikeres.</translation>
+        <translation>Importálás sikeres.</translation>
     </message>
     <message>
         <source>Import failed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Importálás sikertelen.</translation>
     </message>
 </context>
 <context>
     <name>UBImportDocument</name>
     <message>
         <source>Importing file %1...</source>
-        <translation>%1 fájl importálása...</translation>
+        <translation>%1 fájl importálása…</translation>
     </message>
     <message>
         <source>Import successful.</source>
@@ -1790,14 +1812,14 @@ Providing a new name will create a new document.</source>
     <name>UBImportDocumentSetAdaptor</name>
     <message>
         <source>Openboard (set of documents) (*.ubx)</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenBoard (dokumentumkészlet) (*.ubx)</translation>
     </message>
 </context>
 <context>
     <name>UBImportImage</name>
     <message>
         <source>Image Format (</source>
-        <translation>Kép formátum (</translation>
+        <translation>Kép-formátum (</translation>
     </message>
 </context>
 <context>
@@ -1812,25 +1834,25 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Importing page %1 of %2</source>
-        <translation>%2 / %1 oldal importálása</translation>
+        <translation>Oldal importálása: %1/%2</translation>
     </message>
 </context>
 <context>
     <name>UBIntranetPodcastPublisher</name>
     <message>
         <source>Error while publishing video to intranet (%1)</source>
-        <translation>Hiba a videó intranetre való publikálása közben (%1)</translation>
+        <translation>Hiba történt videó közzétételekor az intraneten (%1)</translation>
     </message>
     <message>
         <source>Publishing to Intranet in progress %1 %</source>
-        <translation>Intranetre publikálás folyamatban %1 %</translation>
+        <translation>Az intraneten való közzététel folyamatban van %1%</translation>
     </message>
 </context>
 <context>
     <name>UBIntranetPodcastPublishingDialog</name>
     <message>
         <source>Publish</source>
-        <translation>Publikálás</translation>
+        <translation>Közzététel</translation>
     </message>
 </context>
 <context>
@@ -1936,14 +1958,22 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     </message>
     <message>
         <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
-        <translation type="vanished">elveszítette a &apos;%1&apos; dokumentum repository hozzáférését. Sajnálatosan az alkalmazásnak le kellett állnia, hogy elkerülje az adatsérülést. A legutóbbi változtatások elveszhettek.</translation>
+        <translation type="vanished">elveszítette a(z) „%1” dokumentum repository hozzáférését. Sajnálatosan az alkalmazásnak le kellett állnia, hogy elkerülje az adatsérülést. A legutóbbi változtatások elveszhettek.</translation>
     </message>
     <message>
         <source>Moving page to trash folder...</source>
-        <translation type="vanished">Oldal áthelyezése a kukába...</translation>
+        <translation type="vanished">Oldal áthelyezése a törölt elemek mappába…</translation>
     </message>
     <message>
         <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
+        <translation>Az OpenBoard elvesztette a hozzáférést a(z) „%1” dokumentumtárához. Sajnos az alkalmazást le kell állítani az adatvesztés elkerülése érdekében. A legújabb változások is elveszhetnek.</translation>
+    </message>
+    <message>
+        <source>Renaming pages (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retrieving all your documents (found : %1)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1974,11 +2004,11 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     <name>UBPodcastController</name>
     <message>
         <source>Failed to start encoder ...</source>
-        <translation>Sikertelen a kódoló indítása...</translation>
+        <translation>Sikertelen a kódoló indítása…</translation>
     </message>
     <message>
         <source>No Podcast encoder available ...</source>
-        <translation>Nincs elérhető podcast kódoló ...</translation>
+        <translation>Nincs elérhető podcast kódoló…</translation>
     </message>
     <message>
         <source>Part %1</source>
@@ -1986,7 +2016,7 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     </message>
     <message>
         <source>on your desktop ...</source>
-        <translation>az asztalán ...</translation>
+        <translation>az asztalán…</translation>
     </message>
     <message>
         <source>in folder %1</source>
@@ -2022,11 +2052,11 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     </message>
     <message>
         <source>Publish to Intranet</source>
-        <translation>Publikálás az Intranetre</translation>
+        <translation>Közzététel az Intraneten</translation>
     </message>
     <message>
         <source>Publish to Youtube</source>
-        <translation>Publikálás a YouTubera</translation>
+        <translation>Közzététel a Youtube-on</translation>
     </message>
     <message>
         <source>OpenBoard Cast</source>
@@ -2048,7 +2078,7 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     <name>UBProxyLoginDlg</name>
     <message>
         <source>Proxy Login</source>
-        <translation type="vanished">Proxy belépés</translation>
+        <translation type="vanished">Proxy bejelentkezés</translation>
     </message>
     <message>
         <source>Username:</source>
@@ -2063,7 +2093,7 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     <name>UBPublicationDlg</name>
     <message>
         <source>Publish document on the web</source>
-        <translation type="vanished">Dokumentum publikálása a WEBre</translation>
+        <translation type="vanished">Dokumentum közzététele az interneten</translation>
     </message>
     <message>
         <source>Title:</source>
@@ -2075,7 +2105,7 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     </message>
     <message>
         <source>Publish</source>
-        <translation type="vanished">Publikálás</translation>
+        <translation type="vanished">Közzététel</translation>
     </message>
 </context>
 <context>
@@ -2103,16 +2133,20 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     <name>UBThumbnailAdaptor</name>
     <message>
         <source>Generating preview thumbnails ...</source>
-        <translation>Előképek létrehozása...</translation>
+        <translation>Előképek létrehozása…</translation>
     </message>
     <message>
         <source>%1 thumbnails generated ...</source>
-        <translation>%1 előkép létrehozva...</translation>
+        <translation>%1 előkép létrehozva…</translation>
     </message>
     <message>
         <source>loading thumbnail of page %1</source>
         <translation type="vanished">%1. oldal előképének betöltése</translation>
     </message>
+    <message>
+        <source>Loading thumbnail (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBThumbnailTextItem</name>
@@ -2153,7 +2187,7 @@ Figyelmen kívül hagyja ezeket a hibákat ennél a hosztnál?</translation>
     </message>
     <message>
         <source>Axes</source>
-        <translation type="unfinished"></translation>
+        <translation>Tengelyek</translation>
     </message>
 </context>
 <context>
@@ -2212,7 +2246,7 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>Please wait the import process will start soon...</source>
-        <translation>Kérem várjon. Az importálási folyamat hamarosan elindul...</translation>
+        <translation>Kérem várjon. Az importálási folyamat hamarosan elindul…</translation>
     </message>
     <message>
         <source>Remind me later</source>
@@ -2223,7 +2257,7 @@ Please reboot the application to access the updated documents.</source>
     <name>UBWebPluginWidget</name>
     <message>
         <source>Loading...</source>
-        <translation>Betöltés ...</translation>
+        <translation>Betöltés folyamatban van…</translation>
     </message>
 </context>
 <context>
@@ -2256,7 +2290,7 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>Autos &amp; Vehicles</source>
-        <translation>Autók &amp; Járművek</translation>
+        <translation>Autók és Járművek</translation>
     </message>
     <message>
         <source>Music</source>
@@ -2264,7 +2298,7 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>Pets &amp; Animals</source>
-        <translation>Házi kedvencek @ Állatok</translation>
+        <translation>Háziállatok és Állatok</translation>
     </message>
     <message>
         <source>Sports</source>
@@ -2272,7 +2306,7 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>Travel &amp; Events</source>
-        <translation>Utazás &amp; Események</translation>
+        <translation>Utazás és Események</translation>
     </message>
     <message>
         <source>Gaming</source>
@@ -2284,11 +2318,11 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>People &amp; Blogs</source>
-        <translation>Emberek &amp; Blogok</translation>
+        <translation>Emberek és Webes naplók</translation>
     </message>
     <message>
         <source>News &amp; Politics</source>
-        <translation>Hírek &amp; Politika</translation>
+        <translation>Hírek és Politika</translation>
     </message>
     <message>
         <source>Entertainment</source>
@@ -2300,15 +2334,15 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>Howto &amp; Style</source>
-        <translation>Hogyan Csináld &amp; Stílus</translation>
+        <translation>Hogyan kell és Stílus</translation>
     </message>
     <message>
         <source>Nonprofits &amp; Activism</source>
-        <translation>NonProfit &amp; Aktivisták</translation>
+        <translation>Nonprofit szervezetek és Aktivizmus</translation>
     </message>
     <message>
         <source>Science &amp; Technology</source>
-        <translation>Tudomány &amp; Technológia</translation>
+        <translation>Tudomány és Technológia</translation>
     </message>
 </context>
 <context>
@@ -2361,7 +2395,7 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>%1 of %2 (%3/sec) %4</source>
-        <translation>%1 / %2 (%3/mp) %4</translation>
+        <translation>%1/%2 (%3/mp) %4</translation>
     </message>
     <message>
         <source>?</source>
@@ -2370,7 +2404,7 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>%1 of %2 - Stopped</source>
-        <translation>%1 / %2 - Megállítva</translation>
+        <translation>%1/%2 - Megállítva</translation>
     </message>
     <message>
         <source>bytes</source>
@@ -2430,11 +2464,11 @@ Please reboot the application to access the updated documents.</source>
     <name>WBTabBar</name>
     <message>
         <source>New &amp;Tab</source>
-        <translation>Új fül &amp;T</translation>
+        <translation>Új &amp;Lap</translation>
     </message>
     <message>
         <source>Clone Tab</source>
-        <translation>Fül másolása</translation>
+        <translation>Lap másolása</translation>
     </message>
     <message>
         <source>&amp;Close Tab</source>
@@ -2442,15 +2476,15 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>Close &amp;Other Tabs</source>
-        <translation>Többi fül bezárása &amp;O</translation>
+        <translation>&amp;Többi lap bezárása</translation>
     </message>
     <message>
         <source>Reload Tab</source>
-        <translation>Fül frissítése</translation>
+        <translation>Lap újratöltése</translation>
     </message>
     <message>
         <source>Reload All Tabs</source>
-        <translation>Minden fül frissítése</translation>
+        <translation>Minden lap újratöltése</translation>
     </message>
 </context>
 <context>
@@ -2491,7 +2525,7 @@ Please reboot the application to access the updated documents.</source>
     </message>
     <message>
         <source>Add to Current Document</source>
-        <translation>Hozzaadás az aktuális dokumentumhoz</translation>
+        <translation>Hozzaadás a jelenlegi dokumentumhoz</translation>
     </message>
     <message>
         <source>PDF</source>
@@ -2517,14 +2551,14 @@ Please reboot the application to access the updated documents.</source>
     <name>XPDFRenderer</name>
     <message>
         <source>Processing...</source>
-        <translation type="unfinished"></translation>
+        <translation>Feldolgozás folyamatban van…</translation>
     </message>
 </context>
 <context>
     <name>YouTubePublishingDialog</name>
     <message>
         <source>Publish Podcast to YouTube</source>
-        <translation>Podcast publikálása YouTubera</translation>
+        <translation>Podcast közzététele a YouTube-on</translation>
     </message>
     <message>
         <source>Title</source>
@@ -2645,19 +2679,19 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Creation date</source>
-        <translation type="unfinished"></translation>
+        <translation>Létrehozás dátuma</translation>
     </message>
     <message>
         <source>Update date</source>
-        <translation type="unfinished"></translation>
+        <translation>Frissítés dátuma</translation>
     </message>
     <message>
         <source>Alphabetical order</source>
-        <translation type="unfinished"></translation>
+        <translation>Rendezés betűrendben</translation>
     </message>
     <message>
         <source>Sort Order</source>
-        <translation type="unfinished"></translation>
+        <translation>Rendezési sorrend</translation>
     </message>
 </context>
 <context>
@@ -2744,7 +2778,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>version : …</source>
-        <translation>verziószám: ...</translation>
+        <translation>verziószám: </translation>
     </message>
     <message>
         <source>Licences</source>
@@ -2828,31 +2862,31 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Swap first and second view displays</source>
-        <translation type="unfinished"></translation>
+        <translation>Első és második kijelző megcserélése</translation>
     </message>
     <message>
         <source>Documents Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokumentum üzemmód</translation>
     </message>
     <message>
         <source>Display date column on alphabetical sort</source>
-        <translation type="unfinished"></translation>
+        <translation>Dátum oszlop megjelenítése betűrendben</translation>
     </message>
     <message>
         <source>Empty trash for documents older than</source>
-        <translation type="unfinished"></translation>
+        <translation>A törölt elemek ürítése a következőknél régebbi dokumentumokhoz:</translation>
     </message>
     <message>
         <source>days</source>
-        <translation type="unfinished"></translation>
+        <translation>nap</translation>
     </message>
     <message>
         <source>PDF Rendering</source>
-        <translation type="unfinished"></translation>
+        <translation>PDF-megjelenítő</translation>
     </message>
     <message>
         <source>Improve zoom execution time (can slightly affect rendering quality)</source>
-        <translation type="unfinished"></translation>
+        <translation>Nagyitás végrehajtási idő csökkentése (némileg befolyásolhatja a renderelés minőségét)</translation>
     </message>
 </context>
 <context>
@@ -2863,7 +2897,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Select a flash to trap</source>
-        <translation>Flash kiválasztása a rögzítéshez</translation>
+        <translation type="vanished">Flash kiválasztása a rögzítéshez</translation>
     </message>
     <message>
         <source>about:blank</source>
@@ -2877,5 +2911,9 @@ p, li { white-space: pre-wrap; }
         <source>Create Application</source>
         <translation>Alkalmazás létrehozása</translation>
     </message>
+    <message>
+        <source>Select a content to capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
