@@ -697,11 +697,11 @@
     </message>
     <message>
         <source>Flash Trap</source>
-        <translation>Flash Trap</translation>
+        <translation type="vanished">Flash Trap</translation>
     </message>
     <message>
         <source>Trap Flash Content</source>
-        <translation>Trap flash inhoud</translation>
+        <translation type="vanished">Trap flash inhoud</translation>
     </message>
     <message>
         <source>Web Trap</source>
@@ -839,6 +839,10 @@
         <source>Draw intermediate grid lines</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Capture Web Content</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -896,6 +900,14 @@
         <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Loading scene (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moving cached scenes (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplication</name>
@@ -907,6 +919,10 @@
         <source>Podcast</source>
         <translation>Podcast</translation>
     </message>
+    <message>
+        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplicationController</name>
@@ -1222,6 +1238,10 @@
         <source>Title page</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Refreshing Document Thumbnails View (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1272,6 +1292,10 @@
         <source>Page %0</source>
         <translation>Pagina %0</translation>
     </message>
+    <message>
+        <source>Generating thumbnails for board (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentPublisher</name>
@@ -1960,6 +1984,14 @@ Do you want to ignore these errors for this host?</source>
         <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Renaming pages (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retrieving all your documents (found : %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBPlatformUtils</name>
@@ -2123,6 +2155,10 @@ Do you want to ignore these errors for this host?</source>
         <source>%1 thumbnails generated ...</source>
         <translation>%1 miniaturen opgeladen...</translation>
     </message>
+    <message>
+        <source>Loading thumbnail (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBThumbnailTextItem</name>
@@ -2900,7 +2936,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Select a flash to trap</source>
-        <translation>Te vangen licht selecteren</translation>
+        <translation type="vanished">Te vangen licht selecteren</translation>
     </message>
     <message>
         <source>about:blank</source>
@@ -2914,5 +2950,9 @@ p, li { white-space: pre-wrap; }
         <source>Create Application</source>
         <translation>Applicatie maken</translation>
     </message>
+    <message>
+        <source>Select a content to capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
