@@ -481,7 +481,7 @@
     </message>
     <message>
         <source>Grid Light Background</source>
-        <translation>Jasne rastrowe tło</translation>
+        <translation>Jasne tło w kratkę</translation>
     </message>
     <message>
         <source>Plain Dark Background</source>
@@ -493,7 +493,7 @@
     </message>
     <message>
         <source>Grid Dark Background</source>
-        <translation>Ciemne rastrowe tło</translation>
+        <translation>Ciemne tło w kratkę</translation>
     </message>
     <message>
         <source>Podcast</source>
@@ -561,7 +561,7 @@
     </message>
     <message>
         <source>Highlight </source>
-        <translation>Wyróżnienie</translation>
+        <translation>Wyróżnienie </translation>
     </message>
     <message>
         <source>Ctrl+M</source>
@@ -697,16 +697,15 @@
     </message>
     <message>
         <source>Flash Trap</source>
-        <translation>Pułapka Flash</translation>
+        <translation type="vanished">Pułapka Flash</translation>
     </message>
     <message>
         <source>Trap Flash Content</source>
-        <translation>Złap zawartość Flash</translation>
+        <translation type="vanished">Złap zawartość Flash</translation>
     </message>
     <message>
         <source>Web Trap</source>
-        <translation>
-        </translation>
+        <translation>Pułapka sieciowa</translation>
     </message>
     <message>
         <source>Trap Web Content</source>
@@ -797,50 +796,54 @@
     </message>
     <message>
         <source>Ruled Light Background</source>
-        <translation type="unfinished"></translation>
+        <translation>Jasne tło w linie</translation>
     </message>
     <message>
         <source>Ruled Dark Background</source>
-        <translation type="unfinished"></translation>
+        <translation>Ciemne tło w linie</translation>
     </message>
     <message>
         <source>Open Tutorial</source>
-        <translation type="unfinished"></translation>
+        <translation>Otwórz samouczek</translation>
     </message>
     <message>
         <source>Open the tutorial web page</source>
-        <translation type="unfinished"></translation>
+        <translation>Otwórz stronę samouczka</translation>
     </message>
     <message>
         <source>Reset grid size</source>
-        <translation type="unfinished"></translation>
+        <translation>Zresetuj rozmiar kratki</translation>
     </message>
     <message>
         <source>Small Eraser</source>
-        <translation type="unfinished"></translation>
+        <translation>Mała gumka</translation>
     </message>
     <message>
         <source>Color 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor 1</translation>
     </message>
     <message>
         <source>Color 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor 2</translation>
     </message>
     <message>
         <source>Color 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor 3</translation>
     </message>
     <message>
         <source>Color 4</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor 4</translation>
     </message>
     <message>
         <source>Color 5</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolor 5</translation>
     </message>
     <message>
         <source>Draw intermediate grid lines</source>
+        <translation>Rysuj drobne linie kratki</translation>
+    </message>
+    <message>
+        <source>Capture Web Content</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -886,7 +889,7 @@
     <name>QObject</name>
     <message>
         <source>Element ID = </source>
-        <translation>ID elementu =</translation>
+        <translation>ID elementu = </translation>
     </message>
     <message>
         <source>Content is not supported in destination format.</source>
@@ -900,6 +903,14 @@
         <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
         <translation>Czy na pewno chcesz usunąć 1 stronę z wybranego dokumentu „%0”?</translation>
     </message>
+    <message>
+        <source>Loading scene (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moving cached scenes (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplication</name>
@@ -911,6 +922,10 @@
         <source>Podcast</source>
         <translation>Podkast</translation>
     </message>
+    <message>
+        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplicationController</name>
@@ -939,11 +954,11 @@
     <name>UBBackgroundPalette</name>
     <message>
         <source>Grid size</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozmiar kratki</translation>
     </message>
     <message>
         <source>Draw intermediate grid lines</source>
-        <translation type="unfinished"></translation>
+        <translation>Rysuj drobne linie kratki</translation>
     </message>
 </context>
 <context>
@@ -994,19 +1009,19 @@
     </message>
     <message>
         <source>Saving document...</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisywanie dokumentu...</translation>
     </message>
     <message>
         <source>Document has just been saved...</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokument został właśnie zapisany...</translation>
     </message>
     <message>
         <source>Deleting page %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Usuwanie strony %1</translation>
     </message>
     <message>
         <source>Color</source>
-        <translation type="unfinished">Kolor</translation>
+        <translation>Kolor</translation>
     </message>
 </context>
 <context>
@@ -1024,7 +1039,7 @@
     <name>UBBoardThumbnailsView</name>
     <message>
         <source>Loading page (%1/%2)</source>
-        <translation type="unfinished"></translation>
+        <translation>Ładowanie strony (%1/%2)</translation>
     </message>
 </context>
 <context>
@@ -1074,7 +1089,7 @@
     </message>
     <message>
         <source>Show OpenBoard</source>
-        <translation type="unfinished"></translation>
+        <translation>Pokaż OpenBoard</translation>
     </message>
 </context>
 <context>
@@ -1157,7 +1172,7 @@
     </message>
     <message>
         <source>Failed to import file ... </source>
-        <translation>Importowanie pliku zakończone niepowodzeniem...</translation>
+        <translation>Importowanie pliku zakończone niepowodzeniem... </translation>
     </message>
     <message>
         <source>Import all Images from Folder</source>
@@ -1210,26 +1225,30 @@
     <message numerus="yes">
         <source>duplicated %1 page</source>
         <comment>duplicated %1 pages</comment>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>zduplikowano %1 stronę</numerusform>
+            <numerusform>zduplikowano %1 strony</numerusform>
+            <numerusform>Zduplikowano %1 stron</numerusform>
         </translation>
     </message>
     <message>
         <source>Remove Item</source>
-        <translation type="unfinished"></translation>
+        <translation>Usuń element</translation>
     </message>
     <message>
         <source>Are you sure you want to remove the selected item(s) ?</source>
-        <translation type="unfinished"></translation>
+        <translation>Czy na pewno chcesz usunąć zaznaczone elementy?</translation>
     </message>
     <message>
         <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokument &apos;%1&apos; został utworzony przy użyciu nowszej wersji OpenBoard (%2). Otwierając go możesz stracić niektóre informację. Czy chcesz kontynuować?</translation>
     </message>
     <message>
         <source>Title page</source>
+        <translation>Strona tytułowa</translation>
+    </message>
+    <message>
+        <source>Refreshing Document Thumbnails View (%1/%2)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1282,6 +1301,10 @@
         <source>Page %0</source>
         <translation>Strona %0</translation>
     </message>
+    <message>
+        <source>Generating thumbnails for board (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentPublisher</name>
@@ -1294,32 +1317,34 @@
     <name>UBDocumentReplaceDialog</name>
     <message>
         <source>Accept</source>
-        <translation type="unfinished">Akceptuj</translation>
+        <translation>Akceptuj</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished">Anuluj</translation>
+        <translation>Anuluj</translation>
     </message>
     <message>
         <source>Replace</source>
-        <translation type="unfinished"></translation>
+        <translation>Zastąp</translation>
     </message>
     <message>
         <source>The name %1 is allready used.
 Keeping this name will replace the document.
 Providing a new name will create a new document.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nazwa %1 jest już używana.
+Pozostawienie tej nazwy zastąpi ten dokument.
+Zmiana nazwy na nową utworzy nowy dokument.</translation>
     </message>
 </context>
 <context>
     <name>UBDocumentTreeModel</name>
     <message>
         <source>Trash</source>
-        <translation type="unfinished">Kosz</translation>
+        <translation>Kosz</translation>
     </message>
     <message numerus="yes">
         <source>%1 pages copied</source>
-        <translation type="unfinished">
+        <translation>
             <numerusform>Skopiowano %1 stronę</numerusform>
             <numerusform>Skopiowano %1 strony</numerusform>
             <numerusform>Skopiowano %1 stron</numerusform>
@@ -1327,14 +1352,14 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>My documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Moje dokumenty</translation>
     </message>
 </context>
 <context>
     <name>UBDocumentTreeView</name>
     <message numerus="yes">
         <source>%1 pages copied</source>
-        <translation type="unfinished">
+        <translation>
             <numerusform>Skopiowano %1 stronę</numerusform>
             <numerusform>Skopiowano %1 strony</numerusform>
             <numerusform>Skopiowano %1 stron</numerusform>
@@ -1342,15 +1367,15 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Remove Item</source>
-        <translation type="unfinished"></translation>
+        <translation>Usuń elementy</translation>
     </message>
     <message>
         <source>Are you sure you want to remove the selected item(s) ?</source>
-        <translation type="unfinished"></translation>
+        <translation>Czy na pewno chcesz usunąć zaznaczone elementy?</translation>
     </message>
     <message>
         <source>Copying page %1/%2</source>
-        <translation type="unfinished">Kopiowanie strony %1/%2</translation>
+        <translation>Kopiowanie strony %1/%2</translation>
     </message>
 </context>
 <context>
@@ -1388,14 +1413,14 @@ Providing a new name will create a new document.</source>
     <name>UBDraggableThumbnail</name>
     <message>
         <source>Page %0</source>
-        <translation type="unfinished">Strona %0</translation>
+        <translation>Strona %0</translation>
     </message>
 </context>
 <context>
     <name>UBDraggableThumbnailView</name>
     <message>
         <source>Page %0</source>
-        <translation type="unfinished">Strona %0</translation>
+        <translation>Strona %0</translation>
     </message>
 </context>
 <context>
@@ -1406,23 +1431,23 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Exporting document...</source>
-        <translation type="unfinished">Eksportowanie dokumentu...</translation>
+        <translation>Eksportowanie dokumentu...</translation>
     </message>
     <message>
         <source>Export successful.</source>
-        <translation type="unfinished">Eksportowanie zakończone powodzeniem.</translation>
+        <translation>Eksportowanie zakończone powodzeniem.</translation>
     </message>
     <message>
         <source>Export failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Eksportowanie zakończone niepowodzeniem</translation>
     </message>
     <message>
         <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie udało się wyeksportować do wybranej lokacji. Nie masz wystarczających uprawnień do zapisania pliku.</translation>
     </message>
     <message>
         <source>Export failed: location not writable</source>
-        <translation type="unfinished"></translation>
+        <translation>Eksportowanie nie powiodło się: niemożliwy zapis do lokacji</translation>
     </message>
 </context>
 <context>
@@ -1472,34 +1497,34 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Export to OpenBoard Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Wyeksportuj do formatu OpenBoard</translation>
     </message>
 </context>
 <context>
     <name>UBExportDocumentSetAdaptor</name>
     <message>
         <source>Exporting document...</source>
-        <translation type="unfinished">Eksportowanie dokumentu...</translation>
+        <translation>Eksportowanie dokumentu...</translation>
     </message>
     <message>
         <source>Export successful.</source>
-        <translation type="unfinished">Eksportowanie zakończone powodzeniem.</translation>
+        <translation>Eksportowanie zakończone powodzeniem.</translation>
     </message>
     <message>
         <source>Export failed.</source>
-        <translation type="unfinished">Eksportowanie zakończone niepowodzeniem.</translation>
+        <translation>Eksportowanie zakończone niepowodzeniem.</translation>
     </message>
     <message>
         <source>Failed to export...</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie udało się wyeksportować...</translation>
     </message>
     <message>
         <source>Export as UBX File</source>
-        <translation type="unfinished"></translation>
+        <translation>Wyeksportuj jako plik UBX</translation>
     </message>
     <message>
         <source>Export to OpenBoard UBX Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Wyeksportuj jako plik formatu OpenBoard UBX</translation>
     </message>
 </context>
 <context>
@@ -1691,7 +1716,7 @@ Providing a new name will create a new document.</source>
     <name>UBFeaturesProgressInfo</name>
     <message>
         <source>Loading </source>
-        <translation>Wczytywanie</translation>
+        <translation>Wczytywanie </translation>
     </message>
 </context>
 <context>
@@ -1721,26 +1746,26 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Set as background</source>
-        <translation type="unfinished">Ustaw jako tło</translation>
+        <translation>Ustaw jako tło</translation>
     </message>
 </context>
 <context>
     <name>UBGraphicsMediaItem</name>
     <message>
         <source>Media resource couldn&apos;t be resolved</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie udało się znaleźć zasobu multimedialnego</translation>
     </message>
     <message>
         <source>Unsupported media format</source>
-        <translation type="unfinished"></translation>
+        <translation>Niewspierany format zasobu multimedialnego</translation>
     </message>
     <message>
         <source>Media playback service not found</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie znaleziono usługi odtwarzania</translation>
     </message>
     <message>
         <source>Media error: </source>
-        <translation type="unfinished"></translation>
+        <translation>Błąd multimediów: </translation>
     </message>
 </context>
 <context>
@@ -1783,7 +1808,7 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>Transform as Tool </source>
-        <translation>Przekształć jako narzędzie</translation>
+        <translation>Przekształć jako narzędzie </translation>
     </message>
 </context>
 <context>
@@ -1825,14 +1850,14 @@ Providing a new name will create a new document.</source>
     </message>
     <message>
         <source>OpenBoard (*.ubz)</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenBoard (*.ubz)</translation>
     </message>
 </context>
 <context>
     <name>UBImportDocumentSetAdaptor</name>
     <message>
         <source>Openboard (set of documents) (*.ubx)</source>
-        <translation type="unfinished"></translation>
+        <translation>Openboard (zbiór dokumentów) (*.ubx)</translation>
     </message>
 </context>
 <context>
@@ -1943,27 +1968,27 @@ Czy chcesz ignorować te błędy dla tego hosta?</translation>
     <name>UBOpenSankoreImporterWidget</name>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished">Anuluj</translation>
+        <translation>Anuluj</translation>
     </message>
     <message>
         <source>Open-Sankore Documents Detected</source>
-        <translation type="unfinished"></translation>
+        <translation>Wykryto dokumenty Open-Sankore</translation>
     </message>
     <message>
         <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokumenty Open-Sankoré są dostępne na twoimkomputerze. Możliwy jest ich import do OpenBoard naciskając przycisk &quot;Kontynuuj&quot; by uruchomić aplikację importującą.</translation>
     </message>
     <message>
         <source>Show this panel next time</source>
-        <translation type="unfinished"></translation>
+        <translation>Pokaż ten panel następnym razem</translation>
     </message>
     <message>
         <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
-        <translation type="unfinished"></translation>
+        <translation>Zawsze możesz zyskać dostęp do aplikacji importującej OpenBoard poprzez panel Ustawień w karcie O programie. Uwaga: jeśli zaimportowałaś już dane Open-Sankore, możesz stracić swoje aktualne dokumenty OpenBoard.</translation>
     </message>
     <message>
         <source>Proceed</source>
-        <translation type="unfinished"></translation>
+        <translation>Kontynuuj</translation>
     </message>
 </context>
 <context>
@@ -1978,6 +2003,14 @@ Czy chcesz ignorować te błędy dla tego hosta?</translation>
     </message>
     <message>
         <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
+        <translation>OpenBoard stracił dostęp do repozytorium dokumentów &apos;%1&apos;. Niestety aplikacja musi zostać zamknięta by uniknąć korupcji danych. Ostatnie zmiany również mogą zostać utracone.</translation>
+    </message>
+    <message>
+        <source>Renaming pages (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retrieving all your documents (found : %1)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -2064,7 +2097,7 @@ Czy chcesz ignorować te błędy dla tego hosta?</translation>
     </message>
     <message>
         <source>OpenBoard Cast</source>
-        <translation type="unfinished"></translation>
+        <translation>OpenBoard Cast</translation>
     </message>
 </context>
 <context>
@@ -2123,7 +2156,7 @@ Czy chcesz ignorować te błędy dla tego hosta?</translation>
     <name>UBStartupHintsPalette</name>
     <message>
         <source>Visible next time</source>
-        <translation type="unfinished"></translation>
+        <translation>Pokaż następnym razem</translation>
     </message>
 </context>
 <context>
@@ -2143,12 +2176,16 @@ Czy chcesz ignorować te błędy dla tego hosta?</translation>
         <source>%1 thumbnails generated ...</source>
         <translation>Wygenerowano %1 miniatur...</translation>
     </message>
+    <message>
+        <source>Loading thumbnail (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBThumbnailTextItem</name>
     <message>
         <source>Page %0</source>
-        <translation type="unfinished">Strona %0</translation>
+        <translation>Strona %0</translation>
     </message>
 </context>
 <context>
@@ -2183,7 +2220,7 @@ Czy chcesz ignorować te błędy dla tego hosta?</translation>
     </message>
     <message>
         <source>Axes</source>
-        <translation type="unfinished"></translation>
+        <translation>Osie</translation>
     </message>
 </context>
 <context>
@@ -2461,7 +2498,7 @@ Aby uzyskać dostęp do zaktualizowanych dokumentów, należy ponownie uruchomi
     <name>WBTabBar</name>
     <message>
         <source>New &amp;Tab</source>
-        <translation>Nowa zakładka</translation>
+        <translation>&amp;Nowa zakładka</translation>
     </message>
     <message>
         <source>Clone Tab</source>
@@ -2469,11 +2506,11 @@ Aby uzyskać dostęp do zaktualizowanych dokumentów, należy ponownie uruchomi
     </message>
     <message>
         <source>&amp;Close Tab</source>
-        <translation>Zamknij zakładkę</translation>
+        <translation>&amp;Zamknij kartę</translation>
     </message>
     <message>
         <source>Close &amp;Other Tabs</source>
-        <translation>Zamknij inne zakładki</translation>
+        <translation>Zamknij &amp;Inne karty</translation>
     </message>
     <message>
         <source>Reload Tab</source>
@@ -2534,7 +2571,7 @@ Aby uzyskać dostęp do zaktualizowanych dokumentów, należy ponownie uruchomi
     </message>
     <message>
         <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
-        <translation type="unfinished"></translation>
+        <translation>Pobierz dokument PDF: chcesz pobrać plik PDF, czy dodać go do aktualnego dokumentu OpenBoard?</translation>
     </message>
 </context>
 <context>
@@ -2548,7 +2585,7 @@ Aby uzyskać dostęp do zaktualizowanych dokumentów, należy ponownie uruchomi
     <name>XPDFRenderer</name>
     <message>
         <source>Processing...</source>
-        <translation type="unfinished"></translation>
+        <translation>Przetwarzanie...</translation>
     </message>
 </context>
 <context>
@@ -2591,19 +2628,15 @@ p, li { white-space: pre-wrap; }
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Klikając „Wyślij”, poświadczasz, że posiadasz wszelkie prawa do zawartości lub masz zezwolenie właściciela zawartości na jej publiczne udostępnianie w serwisie YouTube, a także, że zawartość jest zgodna z Warunkami korzystania z serwisu YouTube dostępnymi pod adresem &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
-</translation>
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Klikając „Wyślij”, poświadczasz, że posiadasz wszelkie prawa do zawartości lub masz zezwolenie właściciela zawartości na jej publiczne udostępnianie w serwisie YouTube, a także, że zawartość jest zgodna z Warunkami korzystania z serwisu YouTube dostępnymi pod adresem &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <source>OpenBoard</source>
-        <translation type="unfinished" variants="yes">
-            <lengthvariant>OpenBoard</lengthvariant>
-            <lengthvariant></lengthvariant>
-        </translation>
+        <translation>OpenBoard</translation>
     </message>
     <message>
         <source>Restore credentials on reboot</source>
-        <translation type="unfinished"></translation>
+        <translation>Przywróć dane logowania po restarcie</translation>
     </message>
 </context>
 <context>
@@ -2642,11 +2675,11 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Show preview circle from</source>
-        <translation type="unfinished"></translation>
+        <translation>Pokaż podgląd pędzla od</translation>
     </message>
     <message>
         <source>px</source>
-        <translation type="unfinished"></translation>
+        <translation>px</translation>
     </message>
 </context>
 <context>
@@ -2699,23 +2732,23 @@ p, li { white-space: pre-wrap; }
     <name>documents</name>
     <message>
         <source>OpenBoard Documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokumenty OpenBoard</translation>
     </message>
     <message>
         <source>Creation date</source>
-        <translation type="unfinished"></translation>
+        <translation>Data utworzenia</translation>
     </message>
     <message>
         <source>Update date</source>
-        <translation type="unfinished"></translation>
+        <translation>Data modyfikacji</translation>
     </message>
     <message>
         <source>Alphabetical order</source>
-        <translation type="unfinished"></translation>
+        <translation>Porządek alfabetyczny</translation>
     </message>
     <message>
         <source>Sort Order</source>
-        <translation type="unfinished"></translation>
+        <translation>Porządek sortowania</translation>
     </message>
 </context>
 <context>
@@ -2738,7 +2771,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Display</source>
-        <translation>Wyświetlaj</translation>
+        <translation>Wyświetlanie</translation>
     </message>
     <message>
         <source>Internet</source>
@@ -2858,63 +2891,63 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>On Dark Background</source>
-        <translation type="unfinished">Na ciemnym tle</translation>
+        <translation>Na ciemnym tle</translation>
     </message>
     <message>
         <source>Opacity</source>
-        <translation type="unfinished">Nieprzezroczystość</translation>
+        <translation>Nieprzezroczystość</translation>
     </message>
     <message>
         <source>On Light Background</source>
-        <translation type="unfinished">Na jasnym tle</translation>
+        <translation>Na jasnym tle</translation>
     </message>
     <message>
         <source>Swap first and second view displays</source>
-        <translation type="unfinished"></translation>
+        <translation>Zamień wyświetlacze</translation>
     </message>
     <message>
         <source>Built-in virtual keyboard button size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozmiar klawiszy wyświetlanej klawiatury:</translation>
     </message>
     <message>
         <source>Use system keyboard (recommended)</source>
-        <translation type="unfinished"></translation>
+        <translation>Użyj klawiatury systemowej (zalecane)</translation>
     </message>
     <message>
         <source>Grid</source>
-        <translation type="unfinished"></translation>
+        <translation>Kratka</translation>
     </message>
     <message>
         <source>Open-Sankoré Importer</source>
-        <translation type="unfinished"></translation>
+        <translation>Open-Sankoré Importer</translation>
     </message>
     <message>
         <source>Check if Open-Sankoré data could be imported at launch</source>
-        <translation type="unfinished"></translation>
+        <translation>Sprawdź czy dane Open-Sankoré mogą być zaimportowane przy starcie</translation>
     </message>
     <message>
         <source>Documents Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Tryb dokumentów</translation>
     </message>
     <message>
         <source>Display date column on alphabetical sort</source>
-        <translation type="unfinished"></translation>
+        <translation>Wyświetl kolumnę dat w porządku alfabetycznym</translation>
     </message>
     <message>
         <source>Empty trash for documents older than</source>
-        <translation type="unfinished"></translation>
+        <translation>Usuń dokumenty z kosza, które są starsze niż</translation>
     </message>
     <message>
         <source>days</source>
-        <translation type="unfinished"></translation>
+        <translation>dni</translation>
     </message>
     <message>
         <source>PDF Rendering</source>
-        <translation type="unfinished"></translation>
+        <translation>Renderowanie PDF</translation>
     </message>
     <message>
         <source>Improve zoom execution time (can slightly affect rendering quality)</source>
-        <translation type="unfinished"></translation>
+        <translation>Usprawnij wykonywanie przybliżania (może nieco pogorszyć jakość renderowania)</translation>
     </message>
 </context>
 <context>
@@ -2925,7 +2958,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Select a flash to trap</source>
-        <translation>Wybierz Flash do złapania</translation>
+        <translation type="vanished">Wybierz Flash do złapania</translation>
     </message>
     <message>
         <source>about:blank</source>
@@ -2939,5 +2972,9 @@ p, li { white-space: pre-wrap; }
         <source>Create Application</source>
         <translation>Stwórz aplikację</translation>
     </message>
+    <message>
+        <source>Select a content to capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
