@@ -351,7 +351,7 @@
     </message>
     <message>
         <source>Trap Flash Content</source>
-        <translation>Označiť obsah vo Flashi</translation>
+        <translation type="vanished">Označiť obsah vo Flashi</translation>
     </message>
     <message>
         <source>Import</source>
@@ -539,7 +539,7 @@
     </message>
     <message>
         <source>Flash Trap</source>
-        <translation>Označiť Flash</translation>
+        <translation type="vanished">Označiť Flash</translation>
     </message>
     <message>
         <source>Window Capture</source>
@@ -843,6 +843,10 @@
         <source>Draw intermediate grid lines</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Capture Web Content</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PasswordDialog</name>
@@ -900,6 +904,14 @@
         <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
         <translation>Určite chcete odstrániť 1 stránku z vybraného dokumentu &apos;%0&apos;?</translation>
     </message>
+    <message>
+        <source>Loading scene (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moving cached scenes (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplication</name>
@@ -911,6 +923,10 @@
         <source>Page Size</source>
         <translation>Veľkosť stránky</translation>
     </message>
+    <message>
+        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBApplicationController</name>
@@ -1240,6 +1256,10 @@
         <source>Title page</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Refreshing Document Thumbnails View (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentManager</name>
@@ -1290,6 +1310,10 @@
         <source>Page %0</source>
         <translation>Stránka %0</translation>
     </message>
+    <message>
+        <source>Generating thumbnails for board (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBDocumentReplaceDialog</name>
@@ -2008,6 +2032,14 @@ Chcete ignorovať tieto chyby na tomto serveri?</translation>
         <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Renaming pages (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retrieving all your documents (found : %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBPlatformUtils</name>
@@ -2173,6 +2205,10 @@ Chcete ignorovať tieto chyby na tomto serveri?</translation>
         <source>Generating preview thumbnails ...</source>
         <translation>Vytvárajú sa ukážky miniatúr...</translation>
     </message>
+    <message>
+        <source>Loading thumbnail (%1/%2)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UBThumbnailTextItem</name>
@@ -2952,7 +2988,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Select a flash to trap</source>
-        <translation>Vyberte flash, ktorý chcete označiť</translation>
+        <translation type="vanished">Vyberte flash, ktorý chcete označiť</translation>
     </message>
     <message>
         <source>about:blank</source>
@@ -2966,5 +3002,9 @@ p, li { white-space: pre-wrap; }
         <source>Create Application</source>
         <translation>Vytvoriť aplikáciu</translation>
     </message>
+    <message>
+        <source>Select a content to capture</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
