@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2018 Département de l'Instruction Publique (DIP-SEM)
+ * Copyright (C) 2015-2022 Département de l'Instruction Publique (DIP-SEM)
  *
  * Copyright (C) 2013 Open Education Foundation
  *
@@ -34,6 +34,7 @@
 
 #include "domain/UBGraphicsScene.h"
 #include "board/UBBoardController.h"
+#include "tools/UBAbstractDrawRuler.h"
 
 #include "gui/UBMainWindow.h"
 #include "core/memcheck.h"
@@ -58,7 +59,6 @@ void UBDrawingController::destroy()
 
 UBDrawingController::UBDrawingController(QObject * parent)
     : QObject(parent)
-    , mActiveRuler(NULL)
     , mStylusTool((UBStylusTool::Enum)-1)
     , mLatestDrawingTool((UBStylusTool::Enum)-1)
     , mIsDesktopMode(false)
@@ -322,6 +322,23 @@ void UBDrawingController::setMarkerAlpha(qreal alpha)
     emit colorPaletteChanged();
 }
 
+void UBDrawingController::setActiveRuler(UBAbstractDrawRuler* ruler)
+{
+    mActiveRuler = ruler;
+}
+
+UBAbstractDrawRuler* UBDrawingController::activeRuler() const
+{
+    QGraphicsItem* item = dynamic_cast<QGraphicsItem*>(mActiveRuler.data());
+
+    if (item && item->isVisible())
+    {
+        return mActiveRuler;
+    }
+
+    return nullptr;
+}
+
 
 void UBDrawingController::penToolSelected(bool checked)
 {
