@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2018 Département de l'Instruction Publique (DIP-SEM)
+ * Copyright (C) 2015-2022 Département de l'Instruction Publique (DIP-SEM)
  *
  * Copyright (C) 2013 Open Education Foundation
  *
@@ -100,6 +100,8 @@ class UBGraphicsTextItem : public QGraphicsTextItem, public UBItem, public UBRes
         void activateTextEditor(bool activate);
         void setSelected(bool selected);
         void recolor();
+        void initFontProperties();
+        QFont createDefaultFont();
 
         QString mTypeTextHereLabel;
 
