@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2018 Département de l'Instruction Publique (DIP-SEM)
+ * Copyright (C) 2015-2022 Département de l'Instruction Publique (DIP-SEM)
  *
  * Copyright (C) 2013 Open Education Foundation
  *
@@ -110,32 +110,6 @@ UBGraphicsTextItemDelegate::UBGraphicsTextItemDelegate(UBGraphicsTextItem* pDele
     , delta(5)
 {
     delegated()->setData(UBGraphicsItemData::ItemEditable, QVariant(true));
-    delegated()->setPlainText("");
-
-    QTextCursor curCursor = delegated()->textCursor();
-    QTextCharFormat format;
-    QFont font(createDefaultFont());
-
-    font.setPointSize(UBSettings::settings()->fontPointSize());
-    format.setFont(font);
-    if (UBSettings::settings()->isDarkBackground())
-    {
-        if (UBGraphicsTextItem::lastUsedTextColor == Qt::black)
-            UBGraphicsTextItem::lastUsedTextColor = Qt::white;
-    }
-    else
-    {
-        if (UBGraphicsTextItem::lastUsedTextColor == Qt::white)
-            UBGraphicsTextItem::lastUsedTextColor = Qt::black;
-    }
-    delegated()->setDefaultTextColor(UBGraphicsTextItem::lastUsedTextColor);
-    format.setForeground(QBrush(UBGraphicsTextItem::lastUsedTextColor));
-    curCursor.mergeCharFormat(format);
-    delegated()->setTextCursor(curCursor);
-    delegated()->setFont(font);
-
-    delegated()->adjustSize();
-    delegated()->contentsChanged();
 
     connect(delegated()->document(), SIGNAL(cursorPositionChanged(QTextCursor)), this, SLOT(onCursorPositionChanged(QTextCursor)));
     connect(delegated()->document(), SIGNAL(modificationChanged(bool)), this, SLOT(onModificationChanged(bool)));
@@ -146,31 +120,6 @@ UBGraphicsTextItemDelegate::~UBGraphicsTextItemDelegate()
     // NOOP
 }
 
-QFont UBGraphicsTextItemDelegate::createDefaultFont()
-{
-    QTextCharFormat textFormat;
-
-    QString fFamily = UBSettings::settings()->fontFamily();
-    if (!fFamily.isEmpty())
-        textFormat.setFontFamily(fFamily);
-
-    bool bold = UBSettings::settings()->isBoldFont();
-    if (bold)
-        textFormat.setFontWeight(QFont::Bold);
-
-    bool italic = UBSettings::settings()->isItalicFont();
-    if (italic)
-        textFormat.setFontItalic(true);
-
-    QFont font(fFamily, -1, bold ? QFont::Bold : -1, italic);
-    int pointSize = UBSettings::settings()->fontPointSize();
-    if (pointSize > 0) {
-        font.setPointSize(pointSize);
-    }
-
-    return font;
-}
-
 void UBGraphicsTextItemDelegate::createControls()
 {
     UBGraphicsItemDelegate::createControls();
@@ -314,12 +263,24 @@ void UBGraphicsTextItemDelegate::customize(QFontDialog &fontDialog)
 
             QStringList customFontList =  UBResources::resources()->customFontList();
             int index = 0;
-            foreach (QString dialogFontName, dialogFontNames){
-                if (safeWebFontNames.contains(dialogFontName, Qt::CaseInsensitive) || customFontList.contains(dialogFontName, Qt::CaseSensitive))
+            int remove = 0;
+
+            for (const QString& dialogFontName : dialogFontNames)
+            {
+                if (UBStringUtils::containsPrefix(safeWebFontNames, dialogFontName, Qt::CaseInsensitive) ||
+                        UBStringUtils::containsPrefix(customFontList, dialogFontName, Qt::CaseSensitive))
+                {
+                    stringListModel->removeRows(index, remove);
+                    remove = 0;
                     index++;
+                }
                 else
-                    stringListModel->removeRow(index);
+                {
+                    ++remove;
+                }
             }
+
+            stringListModel->removeRows(index, remove);
         }
     }
     QList<QComboBox*> comboBoxes = fontDialog.findChildren<QComboBox*>();
@@ -336,6 +297,7 @@ void UBGraphicsTextItemDelegate::pickFont()
         QFontDialog fontDialog(static_cast<QGraphicsView*>(UBApplication::boardController->controlView()));
 
         fontDialog.setOption(QFontDialog::DontUseNativeDialog);
+
         fontDialog.setCurrentFont(delegated()->textCursor().charFormat().font());
         customize(fontDialog);
 
@@ -343,6 +305,7 @@ void UBGraphicsTextItemDelegate::pickFont()
         {
             QFont selectedFont = fontDialog.selectedFont();
             UBSettings::settings()->setFontFamily(selectedFont.family());
+            UBSettings::settings()->setFontStyleName(selectedFont.styleName());
             UBSettings::settings()->setBoldFont(selectedFont.bold());
             UBSettings::settings()->setItalicFont(selectedFont.italic());
             UBSettings::settings()->setFontPointSize(selectedFont.pointSize());
@@ -384,6 +347,7 @@ void UBGraphicsTextItemDelegate::pickColor()
             format.setForeground(QBrush(selectedColor));
             curCursor.mergeCharFormat(format);
             delegated()->setTextCursor(curCursor);
+            saveTextCursorFormats();
 
             if (!curCursor.hasSelection() || (curCursor.selectedText().length() == delegated()->toPlainText().length()))
             {
@@ -543,7 +507,7 @@ bool UBGraphicsTextItemDelegate::mouseReleaseEvent(QGraphicsSceneMouseEvent *eve
     mSelectionData.mButtonIsPressed = false;
     qDebug() << "Reporting selection of the cursor (mouse release)" << delegated()->textCursor().selection().isEmpty();
     qDebug() << QString("Anchor: %1\nposition: %2 (mouse mouse release)").arg(delegated()->textCursor().anchor()).arg(delegated()->textCursor().position());
-    updateAlighButtonState();
+    updateAlignButtonState();
 
     if (!UBGraphicsItemDelegate::mouseReleaseEvent(event)) {
         return false;
@@ -564,14 +528,10 @@ bool UBGraphicsTextItemDelegate::keyReleaseEvent(QKeyEvent *event)
         return true;
     }
 
-    switch (event->key()) {
-    case Qt::Key_Left:
-    case Qt::Key_Right:
-    case Qt::Key_Up:
-    case Qt::Key_Down:
-        updateAlighButtonState();
-        break;
-    }
+    // to be sure the save/restore TextCursorFormats mechanism is always up-to-date
+    // and because if some text is selected, almost any typed key can clear the selection before
+    // keyReleaseEvent is called, it's safer to call updateAlignButtonState everytime a key is released
+    updateAlignButtonState();
 
     qDebug() << "Key has been released" << QString::number(event->key(), 16);
     return true;
@@ -685,6 +645,7 @@ void UBGraphicsTextItemDelegate::ChangeTextSize(qreal factor, textChangeMode cha
     cursor.setPosition (cursorPos, QTextCursor::KeepAnchor);
 
     delegated()->setTextCursor(cursor);
+    saveTextCursorFormats();
 }
 
 void UBGraphicsTextItemDelegate::recolor()
@@ -774,9 +735,10 @@ void UBGraphicsTextItemDelegate::recolor()
     cursor.setPosition (cursorPos, QTextCursor::KeepAnchor);
 
     delegated()->setTextCursor(cursor);
+    saveTextCursorFormats();
 }
 
-void UBGraphicsTextItemDelegate::updateAlighButtonState()
+void UBGraphicsTextItemDelegate::updateAlignButtonState()
 {
     if (!mAlignButton) {
         return;
@@ -844,7 +806,10 @@ void UBGraphicsTextItemDelegate::restoreTextCursorFormats()
 
     QTextCursor tcrsr = delegated()->textCursor();
     tcrsr.setPosition(mSelectionData.position);
-    tcrsr.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor, steps);
+    if (mSelectionData.position >= mSelectionData.anchor)
+        tcrsr.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor, steps);
+    else
+        tcrsr.movePosition(QTextCursor::Right, QTextCursor::KeepAnchor, steps);
     delegated()->setTextCursor(tcrsr);
 }
 
@@ -864,6 +829,7 @@ QVariant UBGraphicsTextItemDelegate::itemChange(QGraphicsItem::GraphicsItemChang
             {
                 c.clearSelection();
                 delegated()->setTextCursor(c);
+                saveTextCursorFormats();
             }
         }
     }
