@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2018 Département de l'Instruction Publique (DIP-SEM)
+ * Copyright (C) 2015-2022 Département de l'Instruction Publique (DIP-SEM)
  *
  * Copyright (C) 2013 Open Education Foundation
  *
@@ -121,9 +121,6 @@ class WBBrowserWindow : public QWidget
 
         void tabCurrentChanged(int);
 
-        void bookmarks();
-        void addBookmark();
-
         void showTabAtTop(bool attop);
 
         void aboutToShowBackMenu();
